==> open-xchange-realtime-core_7.4.2.orig.tar.bz2: open-xchange-realtime-core-7.4.2/com.openexchange.realtime/src/com/openexchange/realtime/cleanup/LocalRealtimeCleanupImpl.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.realtime.cleanup;

import java.util.Collection;
import java.util.SortedMap;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceReference;
import org.osgi.util.tracker.ServiceTracker;
import com.openexchange.realtime.packet.ID;

/**
 * {@link LocalRealtimeCleanupImpl}
 * 
 * @author <a href="mailto:marc.arens@open-xchange.com">Marc Arens</a>
 */
public class LocalRealtimeCleanupImpl extends ServiceTracker<RealtimeJanitor, RealtimeJanitor> implements LocalRealtimeCleanup {

    public LocalRealtimeCleanupImpl(BundleContext bundleContext) {
        super(bundleContext, RealtimeJanitor.class, null);
    }

    /**
     * Get all currently tracked {@link RealtimeJanitor}s
     * 
     * @return all currently tracked {@link RealtimeJanitor}s
     */
    private Collection<RealtimeJanitor> getJanitors() {
        SortedMap<ServiceReference<RealtimeJanitor>, RealtimeJanitor> trackedJanitors = getTracked();
        return trackedJanitors.values();
    }

    @Override
    public void cleanForId(ID id) {
        Collection<RealtimeJanitor> janitors = getJanitors();
        for (RealtimeJanitor realtimeJanitor : janitors) {
            realtimeJanitor.cleanupForId(id);
        }
    }

}

==> open-xchange-realtime-core_7.6.0.orig.tar.bz2: open-xchange-realtime-core-7.6.0/com.openexchange.realtime/src/com/openexchange/realtime/cleanup/LocalRealtimeCleanupImpl.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2014 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.realtime.cleanup;

import java.util.Collection;
import java.util.SortedMap;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceReference;
import org.osgi.util.tracker.ServiceTracker;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import com.openexchange.realtime.packet.ID;

/**
 * {@link LocalRealtimeCleanupImpl}
 * 
 * @author <a href="mailto:marc.arens@open-xchange.com">Marc Arens</a>
 */
public class LocalRealtimeCleanupImpl extends ServiceTracker<RealtimeJanitor, RealtimeJanitor> implements LocalRealtimeCleanup {

    private static final Logger LOG = LoggerFactory.getLogger(LocalRealtimeCleanupImpl.class);
    
    public LocalRealtimeCleanupImpl(BundleContext bundleContext) {
        super(bundleContext, RealtimeJanitor.class, null);
    }

    /**
     * Get all currently tracked {@link RealtimeJanitor}s
     * 
     * @return all currently tracked {@link RealtimeJanitor}s
     */
    private Collection<RealtimeJanitor> getJanitors() {
        SortedMap<ServiceReference<RealtimeJanitor>, RealtimeJanitor> trackedJanitors = getTracked();
        return trackedJanitors.values();
    }

    @Override
    public void cleanForId(ID id) {
        LOG.debug("Starting local realtime cleanup for ID: {}", id);
        Collection<RealtimeJanitor> janitors = getJanitors();
        for (RealtimeJanitor realtimeJanitor : janitors) {
            realtimeJanitor.cleanupForId(id);
        }
    }

}
